==> owncloud-app-contacts-2%3A1.3.1.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/pt_BR.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contatos",
    "Address book name" : "Nome do livro de endereços",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "A imagem selecionada é grande demais (máximo 1MB)",
    "No contacts in here" : "Nenhum contato aqui",
    "Name" : "Nome",
    "Organization" : "Organização",
    "Title" : "Título",
    "Add field ..." : "Adicionar campo...",
    "Add contact" : "Adicionar contatos",
    "No search result for {query}" : "Nenhum resultado de busca para {query}",
    "All contacts" : "Todos os contatos",
    "Not grouped" : "Não agrupado",
    "Post Office Box" : "Caixa de Correio",
    "Postal Code" : "Código Postal",
    "City" : "Cidade",
    "State or province" : "Estado ou província",
    "Country" : "País",
    "Address" : "Endereço",
    "(new group)" : "(novo grupo)",
    "New contact" : "Novo contato",
    "{addressbook} shared by {owner}" : "{addressbook} compartilhado por {owner}",
    "No contacts in file. Only VCard files are allowed." : "Nenhum contato em arquivo. Somente arquivos vCard são permitidos.",
    "Nickname" : "Apelido",
    "Notes" : "Notas",
    "Website" : "Website",
    "Federated Cloud ID" : "ID de núvem Associada",
    "Home" : "Casa",
    "Work" : "Trabalho",
    "Other" : "Outro",
    "Groups" : "Grupos",
    "Birthday" : "Aniversário",
    "Email" : "E-mail",
    "Instant messaging" : "Mensagem instantânea",
    "Phone" : "Telefone",
    "Mobile" : "Móvel",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do trabalho",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Social Network" : "Rêde Social",
    "Settings" : "Configurações"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/pt_BR.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contatos",
    "Address book name" : "Nome do livro de endereços",
    "Import" : "Importar",
    "The selected image is too big (max 1MB)" : "A imagem selecionada é grande demais (máximo 1MB)",
    "No contacts in here" : "Nenhum contato aqui",
    "Name" : "Nome",
    "Organization" : "Organização",
    "Title" : "Título",
    "Add field ..." : "Adicionar campo...",
    "+ New contact" : "+ Novo contato",
    "No search result for {query}" : "Nenhum resultado de busca para {query}",
    "_%n contact_::_%n contacts_" : ["%n contato","%n contatos"],
    "Post office box" : "Caixa de correio",
    "Postal code" : "Código postal",
    "City" : "Cidade",
    "State or province" : "Estado ou província",
    "Country" : "País",
    "Address" : "Endereço",
    "(new group)" : "(novo grupo)",
    "Last name" : "Sobrenome",
    "First name" : "Primeiro nome",
    "Additional names" : "Nomes adicionais",
    "Prefix" : "Prefixo",
    "Suffix" : "Sufixo",
    "All contacts" : "Todos os contatos",
    "Not grouped" : "Não agrupado",
    "New contact" : "Novo contato",
    "{addressbook} shared by {owner}" : "{addressbook} compartilhado por {owner}",
    "No contacts in file. Only VCard files are allowed." : "Nenhum contato em arquivo. Somente arquivos vCard são permitidos.",
    "Nickname" : "Apelido",
    "Detailed name" : "Nome detalhado",
    "Notes" : "Notas",
    "Website" : "Website",
    "Federated Cloud ID" : "ID de núvem Associada",
    "Home" : "Casa",
    "Work" : "Trabalho",
    "Other" : "Outro",
    "Groups" : "Grupos",
    "Birthday" : "Aniversário",
    "Anniversary" : "Aniversário",
    "Date of death" : "Data da morte",
    "Email" : "E-mail",
    "Instant messaging" : "Mensagem instantânea",
    "Phone" : "Telefone",
    "Mobile" : "Móvel",
    "Fax" : "Fax",
    "Fax home" : "Fax de casa",
    "Fax work" : "Fax do trabalho",
    "Pager" : "Pager",
    "Voice" : "Voz",
    "Social network" : "Rede social",
    "Settings" : "Configurações"
},
"nplurals=2; plural=(n > 1);");
